@@ -1,4 +1,4 @@
-if (require("gt") && packageVersion("insight") >= "0.12.0.1") {
+if (require("testthat") && require("gt") && require("dplyr")) {
 
   # display and print method works - markdown -----------------------------
 
@@ -38,4 +38,19 @@ if (require("gt") && packageVersion("insight") >= "0.12.0.1") {
 
     expect_snapshot(print(summary(correlation(iris)), format = "html"), cran = FALSE)
   })
+
+  test_that("as.matrix works", {
+    set.seed(123)
+    mat1 <- dplyr::select(mtcars, am, wt, hp) %>%
+      correlation() %>%
+      as.matrix()
+
+    set.seed(123)
+    mat2 <- dplyr::select(mtcars, am, wt, hp) %>%
+      group_by(am) %>%
+      correlation() %>%
+      as.matrix()
+
+    expect_snapshot(list(mat1, mat2))
+  })
 }
